# API

## EHRData

```{eval-rst}
.. module:: ehrdata

.. autosummary::
    :toctree: generated

    EHRData
```

## Input-Output

```{eval-rst}
.. module:: ehrdata.io
.. currentmodule:: ehrdata

.. autosummary::
    :toctree: generated

    io.omop.setup_connection
    io.omop.setup_obs
    io.omop.setup_variables
    io.omop.setup_interval_variables
```

## Datasets

```{eval-rst}
.. module:: ehrdata.dt
.. currentmodule:: ehrdata

.. autosummary::
    :toctree: generated

    dt.mimic_iv_omop
    dt.gibleed_omop
    dt.synthea27nj_omop
    dt.physionet2012
```

## Tools

```{eval-rst}
.. module:: ehrdata.tl
.. currentmodule:: ehrdata

.. autosummary::
    :toctree: generated

    tl.omop.EHRDataset
```

## Plotting

```{eval-rst}
.. module:: ehrdata.pl
.. currentmodule:: ehrdata

.. autosummary::
    :toctree: generated

    pl.vitessce.gen_config
```
